# Qt Creator

Open the top `CMakeLists.txt` in *Qt Creator*.

Upon opening the first time, *Qt Creator* will ask you to configure the project.

You can select one of the presets from `CMakePresets.json` or use a different
toolchain to build the project.

As of this date (2024/12), *Qt Creator* builds are stored under local `build`
folder by default.
